asr.setinfo
===========

.. automodule:: asr.setinfo

   
   
   .. rubric:: Functions

   
   .. autofunction:: check_key_value
   
   

   
   
   .. rubric:: Classes

   
   .. autoclass:: KeyValuePair
      :members:
   
   

   
   
   